@@ -25,13 +25,16 @@ describe 'glance::api' do
       :workers                  => '7',
       :show_image_direct_url    => '<SERVICE DEFAULT>',
       :show_multiple_locations  => '<SERVICE DEFAULT>',
+      :filesystem_store_metadata_file => '<SERVICE DEFAULT>',
+      :filesystem_store_file_perm => '<SERVICE DEFAULT>',
       :location_strategy        => '<SERVICE DEFAULT>',
       :purge_config             => false,
-      :known_stores             => false,
       :delayed_delete           => '<SERVICE DEFAULT>',
       :scrub_time               => '<SERVICE DEFAULT>',
       :default_store            => false,
       :image_cache_dir          => '/var/lib/glance/image-cache',
+      :enabled_import_methods   => '<SERVICE DEFAULT>',
+      :node_staging_uri         => '<SERVICE DEFAULT>',
       :image_member_quota       => '<SERVICE DEFAULT>',
       :image_cache_stall_time   => '<SERVICE DEFAULT>',
       :image_cache_max_size     => '<SERVICE DEFAULT>',
@@ -66,10 +69,14 @@ describe 'glance::api' do
         :workers                  => '5',
         :show_image_direct_url    => true,
         :show_multiple_locations  => true,
+        :filesystem_store_metadata_file => '/etc/glance/glance-metadata-file.conf',
+        :filesystem_store_file_perm => '0644',
         :location_strategy        => 'store_type',
         :delayed_delete           => 'true',
         :scrub_time               => '10',
         :image_cache_dir          => '/tmp/glance',
+        :enabled_import_methods   => 'glance-direct,web-download',
+        :node_staging_uri         => '/tmp/staging',
         :image_member_quota       => '128',
         :image_cache_stall_time   => '10',
         :image_cache_max_size     => '10737418240',
@@ -128,6 +135,7 @@ describe 'glance::api' do
             'delayed_delete',
             'scrub_time',
             'image_cache_dir',
+            'node_staging_uri',
             'image_member_quota',
             'enable_v1_api',
             'enable_v2_api',
@@ -138,6 +146,12 @@ describe 'glance::api' do
           end
         end
 
+        it 'is_expected.to lay down default enabled_import_methods config' do
+          # Verify brackets "[]" are added to satisfy the ListOpt syntax.
+          is_expected.to contain_glance_api_config("DEFAULT/enabled_import_methods").with_value(
+                           "[%s]" % param_hash[:enabled_import_methods])
+        end
+
         it 'is_expected.to lay down default cache config' do
           [
             'registry_host',
@@ -158,6 +172,15 @@ describe 'glance::api' do
           end
         end
 
+        it 'is_expected.to lay down default glance_store api config' do
+          [
+            'filesystem_store_metadata_file',
+            'filesystem_store_file_perm',
+          ].each do |config|
+            is_expected.to contain_glance_api_config("glance_store/#{config}").with_value(param_hash[config.intern])
+          end
+        end
+
         it 'is_expected.to lay down default task & taskflow_executor config' do
           is_expected.to contain_glance_api_config('task/task_time_to_live').with_value(param_hash[:task_time_to_live])
           is_expected.to contain_glance_api_config('task/task_executor').with_value(param_hash[:task_executor])
@@ -278,7 +301,7 @@ describe 'glance::api' do
         default_params
       end
 
-      it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('false') }
+      it { is_expected.to_not contain_glance_api_config('glance_store/stores').with_value('<SERVICE DEFAULT>') }
     end
 
     describe 'with stores override' do
@@ -318,18 +341,7 @@ describe 'glance::api' do
       it { is_expected.to contain_glance_api_config('glance_store/stores').with_value('file,http') }
     end
 
-    describe 'with both stores and known_stores provided' do
-      let :params do
-        default_params.merge({
-          :stores       => ['file'],
-          :known_stores => ['glance.store.http.store'],
-        })
-      end
-
-      it { is_expected.to raise_error(Puppet::Error, /known_stores and stores cannot both be assigned values/) }
-    end
-
-    describe 'with known_stores not set but with default_store' do
+    describe 'with default_store' do
       let :params do
         default_params.merge({
           :default_store => 'file',
